@@ -1,9 +1,8 @@
 package prompt
 
 import (
+	"os/exec"
 	"strings"
-
-	exec "golang.org/x/sys/execabs"
 )
 
 func KDialogMfaPrompt(mfaSerial string) (string, error) {
@@ -18,5 +17,7 @@ func KDialogMfaPrompt(mfaSerial string) (string, error) {
 }
 
 func init() {
-	Methods["kdialog"] = KDialogMfaPrompt
+	if _, err := exec.LookPath("kdialog"); err == nil {
+		Methods["kdialog"] = KDialogMfaPrompt
+	}
 }
